/*
 *   SPARK.POV - test file for SPARK.INC and RIBCYL.INC
 *
 *   I wanted to be able to do threaded cylinders.  Well, they can be 
 *   done, but aren't easy.  This package is the result of my experiments.
 *   I would be interested in any ideas for improvements, particularly
 *   in the area of rendering speed!
 *
 *   This is an image of a spark plug.  Because of the large numbers of
 *   quartic surfaces used, it is very time-consuming.  I suggest using
 *   no, or very conservative (>0.5), antialiasing.  The 640x480 file 
 *   (SPARK.TGA) included in this package took 4 days on my 20 Mhz 386 
 *   w/80387 with parameters "q9 a0.3".  
 *
 *   The TGA image looks best when viewed on a HiColor-capable SVGA card.
 *   A 256 color GIF file, SPARK.GIF, was prepared with PICLAB version 
 *   1.82 (by Danial Crocker and Stone Soup Group) and uploaded separately.
 *
 *   Note:  this file requires LOTS of memory.  I set the Region setting
 *          with POVMOD.EXE to 8M.
 *
 *   The files in this package:
 *
 *      SPARK.POV, SPARK.INC and RIBCYL.INC
 *      MADEIN.GIF, RN9YC.GIF
 *
 *   John Lowery
 *   71075, 1401
 */


#include "shapes.inc"
#include "colors.inc"
#include "textures.inc"
#include "ribcyl.inc"           // included in this package
#include "spark.inc"            // included in this package

camera {
   location < 1.5  5  -4>
   direction <0.0 0.0 2.5>      // away from camera is +z
   up  <0.0  1.0  0.0>          // up is +y
   right <1.33333 0.0 0.0>      // right is +x
   look_at <-0.15 0.39 0>       // look at the center of the plug
}

object {
   light_source { <-20  20.0  -20.0>   // lighting from over our left shoulder
      color White
   }
}

object {
   light_source { <20  20.0  -20.0>   // lighting from over our right shoulder
      color White
   }
}

// A nice plane, for contrast
object {
   plane { <0 1 0> 0}
   texture { Glossy color NavyBlue }
}

// the spark plug
composite { Spark_Plug 
  translate <0 0.39 0>  // lift it up out of the plane
}
